<?php
/**
 * Helper methods to call functions and instance objects.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * http://www.gnu.org/copyleft/gpl.html
 *
 * @file
 */

class MWFunction {

	/**
	 * @param string $class
	 * @param array $args
	 * @return object
	 * @deprecated 1.25 Use ObjectFactory::getObjectFromSpec() instead
	 */
	public static function newObj( $class, $args = array() ) {
		wfDeprecated( __METHOD__, '1.25' );

		return ObjectFactory::getObjectFromSpec( array(
			'class' => $class,
			'args' => $args,
			'closure_expansion' => false,
		) );
	}
}
